@@ -400,9 +400,8 @@ class IO(object):
         if not os.path.exists(experimentdirectory):
             return False
         experiment = []
-
         for files in os.listdir(experimentdirectory):
-            if files.endswith('.frd'):
+            if files.endswith('.frd') and not files.startswith('._'):
                 Xdata = []
                 Ydata = []
                 StepName = []
@@ -459,19 +458,33 @@ class IO(object):
 
                 newbuffer = self.data.new_buffer()
 
+                ### copy and paste of 'interstepcorrection' method from historical fortebiopkg. edited to suit
+                for j in range(0, len(Ydata) - 1):
+                    if Ydata[j][-1] > Ydata[j + 1][0]:
+                        ydif = Ydata[j][-1] - Ydata[j + 1][0]
+                        for k in range(0, len(Ydata[j + 1])):
+                            Ydata[j + 1][k] += ydif
+                    else:
+                        ydif = Ydata[j + 1][0] - Ydata[j][-1]
+                        for k in range(0, len(Ydata[j + 1])):
+                            Ydata[j + 1][k] -= ydif
+                for j in range(0, len(Xdata) - 1):
+                    if Xdata[j][-1] < Xdata[j + 1][0]:
+                        xdif = Xdata[j + 1][0] - Xdata[j][-1]
+                        for k in range(0, len(Xdata[j + 1])):
+                            Xdata[j + 1][k] -= xdif
+                    else:
+                        xdif = Xdata[j][-1] - Xdata[j + 1][0]
+                        for k in range(0, len(Xdata[j + 1])):
+                            Xdata[j + 1][k] -= xdif
+
                 for segment in Xdata:
                     newbuffer.data.x.append(segment)
                     newbuffer.plot.axis.x.lines.append(segment[0])
 
-                y_segments = [] # used to save corrected y_data in meta_dict
-                for j, segment in enumerate(Ydata):
-                    signal_shift = 0.0
-                    if j > 0:
-                        signal_shift = segment[1] - Ydata[j-1][-1]
-                    cor_y = segment - signal_shift
-                    newbuffer.data.y.append(cor_y)
-                    y_segments.append(cor_y)
-
+                newbuffer.data.x.set(np.concatenate(Xdata, axis=None))
+                newbuffer.data.y.set(np.concatenate(Ydata, axis=None))
+                ###
                 newbuffer.data.z.set([float(MolarConcentration[-2])] * newbuffer.data.y.length())
 
                 newbuffer.comments.set([str(SensorInfo) + " on " + str(SensorType) + " vs " +
@@ -481,7 +494,7 @@ class IO(object):
                 newbuffer.plot.axis.x.title.set("Time (s)")
                 newbuffer.plot.axis.y.title.set("Response (nm)")
                 newbuffer.plot.axis.x.lines.show()
-                newbuffer.meta_dict = {'xData': Xdata, 'yData': y_segments,
+                newbuffer.meta_dict = {'xData': Xdata, 'yData': Ydata,
                                        'stepName': StepName, 'actualTime': ActualTime, 'sensorType': SensorType,
                                        'stepStatus': StepStatus, 'stepType': StepType, 'concentration': Concentration,
                                        'molarConcentration':MolarConcentration, 'sampleID':SampleID,
